@@ -54,10 +54,10 @@ IconItem::IconItem(QQuickItem *parent)
       m_animValue(0)
 {
     m_animation = new QPropertyAnimation(this);
-    connect(m_animation, SIGNAL(valueChanged(QVariant)),
-            this, SLOT(valueChanged(QVariant)));
-    connect(m_animation, SIGNAL(finished()),
-            this, SLOT(animationFinished()));
+    connect(m_animation, &QPropertyAnimation::valueChanged,
+            this, &IconItem::valueChanged);
+    connect(m_animation, &QPropertyAnimation::finished,
+            this, &IconItem::animationFinished);
     m_animation->setTargetObject(this);
     m_animation->setEasingCurve(QEasingCurve::InOutQuad);
     m_animation->setDuration(250); //FIXME from theme
@@ -73,8 +73,8 @@ IconItem::IconItem(QQuickItem *parent)
     connect(this, &QQuickItem::windowChanged,
             this, &IconItem::schedulePixmapUpdate);
 
-    connect(this, SIGNAL(overlaysChanged()),
-            this, SLOT(schedulePixmapUpdate()));
+    connect(this, &IconItem::overlaysChanged,
+            this, &IconItem::schedulePixmapUpdate);
 
     connect(this, &IconItem::implicitWidthChanged, this, &IconItem::implicitWidthChanged2);
     connect(this, &IconItem::implicitHeightChanged, this, &IconItem::implicitHeightChanged2);
@@ -175,13 +175,10 @@ void IconItem::setSource(const QVariant &source)
                 //try as a svg icon from plasma theme
                 m_svgIcon->setImagePath(QLatin1String("icons/") + sourceString.section('-', 0, 0));
                 m_svgIcon->setContainsMultipleImages(true);
-            //invalidate the image path to recalculate it later
-            } else {
-                m_svgIcon->setImagePath(QString());
             }
 
             //success?
-            if (m_svgIcon->isValid() && m_svgIcon->hasElement(sourceString)) {
+            if (m_usesPlasmaTheme && m_svgIcon->isValid() && m_svgIcon->hasElement(sourceString)) {
                 m_icon = QIcon();
                 m_svgIconName = sourceString;
                 //ok, svg not available from the plasma theme
