@@ -43,11 +43,33 @@ class PLASMA_EXPORT Corona : public QObject
     Q_OBJECT
     Q_PROPERTY(bool isStartupCompleted READ isStartupCompleted NOTIFY startupCompleted)
     Q_PROPERTY(Package package READ package NOTIFY packageChanged)
+    Q_PROPERTY(KPackage::Package kPackage READ kPackage NOTIFY kPackageChanged)
 
 public:
     explicit Corona(QObject *parent = 0);
     ~Corona();
 
+#ifndef PLASMA_NO_DEPRECATED
+    /**
+     * Accessor for the associated Package object if any.
+     * A Corona package defines how Containments are laid out in a View,
+     * ToolBoxes, default layout, error messages
+     * and in genelal all the furniture specific of a particular
+     * device form factor.
+     *
+     * @deprecated use kPackage instead
+     * @return the Package object, or an invalid one if none
+     * @since 5.0
+     **/
+    PLASMA_DEPRECATED Plasma::Package package() const;
+
+    /**
+     * Setting the package name
+     * @deprecated use setKPackage instead
+     */
+    PLASMA_DEPRECATED void setPackage(const Plasma::Package &package);
+#endif
+
     /**
      * Accessor for the associated Package object if any.
      * A Corona package defines how Containments are laid out in a View,
@@ -56,14 +78,15 @@ public:
      * device form factor.
      *
      * @return the Package object, or an invalid one if none
-     * @since 5.0
+     * @since 5.5
      **/
-    Plasma::Package package() const;
+    KPackage::Package kPackage() const;
 
     /**
-     * Setting the package name
+     * Setting the package for the corona
+     * @since 5.5
      */
-    void setPackage(const Plasma::Package &package);
+    void setKPackage(const KPackage::Package &package);
 
     /**
      * @return all containments on this Corona
@@ -99,11 +122,9 @@ public:
     Containment *createContainment(const QString &name, const QVariantList &args = QVariantList());
 
     /**
-     * Returns the Containment, if any, for a given physical screen and desktop
+     * Returns the Containment, if any, for a given physical screen
      *
      * @param screen number of the physical screen to locate
-     * @param desktop the virtual desktop) to locate; if < 0 then it will
-     *        simply return the first Containment associated with screen
      */
     Containment *containmentForScreen(int screen) const;
 
@@ -243,10 +264,20 @@ public Q_SLOTS:
 Q_SIGNALS:
     /**
      * This signal indicates a new containment has been added to
-     * the Corona
+     * the Corona: it may occur after creation or restore from config
      */
     void containmentAdded(Plasma::Containment *containment);
 
+    /**
+     * This signal indicates a new containment has been created
+     * in the Corona. Compared to containmentAdded it can only happen
+     * after the creation of a new containment.
+     *
+     * @see containmentAdded
+     * @since 5.16
+     */
+    void containmentCreated(Plasma::Containment *containment);
+
     /**
      * This signal indicates that a containment has been newly
      * associated (or dissociated) with a physical screen.
@@ -261,15 +292,20 @@ Q_SIGNALS:
     void configSynced();
 
     /**
-     * This signal indicates that a change in available screen gemetry occurred.
+     * This signal indicates that a change in available screen geometry occurred.
      */
     void availableScreenRegionChanged();
 
     /**
-     * This signal indicates that a change in available screen gemetry occurred.
+     * This signal indicates that a change in available screen geometry occurred.
      */
     void availableScreenRectChanged();
 
+    /**
+     * This signal indicates that a change in geometry for the screen occurred.
+     */
+    void screenGeometryChanged(int id);
+
     /**
      * emitted when immutability changes.
      * this is for use by things that don't get constraints events, like plasmaapp.
@@ -278,13 +314,24 @@ Q_SIGNALS:
      */
     void immutabilityChanged(Plasma::Types::ImmutabilityType immutability);
 
+#ifndef PLASMA_NO_DEPRECATED
+    /**
+     * Emitted when the package for this corona has been changed.
+     * Shells must support changing the shell package on the fly (for instance due to device form factor changing)
+     *
+     * @deprecated use kPackageChanged instead
+     * @param package the new package that defines the Corona furniture and behavior
+     */
+    PLASMA_DEPRECATED void packageChanged(const Plasma::Package &package);
+#endif
+
     /**
      * Emitted when the package for this corona has been changed.
      * Shells must support changing the shell package on the fly (for instance due to device form factor changing)
      *
      * @param package the new package that defines the Corona furniture and behavior
      */
-    void packageChanged(const Plasma::Package &package);
+    void kPackageChanged(const KPackage::Package &package);
 
     /**
      * Emitted when the startup phase has been completed
@@ -323,6 +370,7 @@ private:
     Q_PRIVATE_SLOT(d, void containmentDestroyed(QObject *))
     Q_PRIVATE_SLOT(d, void syncConfig())
     Q_PRIVATE_SLOT(d, void toggleImmutability())
+    Q_PRIVATE_SLOT(d, void containmentReady(bool))
 
     friend class CoronaPrivate;
     friend class View;
